@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2004 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "displayFonte.cpp"
 // created      : 1999-09-05
-// updates      : 2002-08-02
+// updates      : 2004-08-01
 //-----------------------------------------------------------------------------
 // functions    : void  Aff_Score_Player_One()
 //              : void  Aff_Level_Player_One(int dec_x, int dec_y, int numero_level)
@@ -79,16 +79,16 @@ static char             pASCIIlevel[10] = { "LEVEL??\0\0" };
 //------------------------------------------------------------------------------
 void Aff_Score_Player_One()
 {
-  unsigned int            _iIndex;
-  unsigned int            _iOffset;
-  unsigned int            i;
+  unsigned int _iIndex;
+  unsigned int _iOffset;
+  unsigned int i;
 
   if(player_score != old_player_score)                         //score update ?
     for(i = 0; i < NBR_CHIF_SCORE; i++)
       aff_player_score[i].anim_font = 1;                       //1=update display
   old_player_score = player_score;
   iScoreXWindow = 1;                                           //1=update player's score points
-  for(int i = 0; i < NBR_CHIF_SCORE; i++)
+  for(i = 0; i < NBR_CHIF_SCORE; i++)
   {
     if(aff_player_score[i].anim_font)
     {
