@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2003 TLK Games all rights reserved
+// copyright (c) 1998-2004 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "etbfonte.cpp"
 // created      : ?
-// updates      : 2003-07-01
+// updates      : 2004-08-01
 //-----------------------------------------------------------------------------
 // description  : Implementation de la classe _etfonte1
 //                display simples fontes in 8*8 pixels
@@ -79,7 +79,6 @@ extern LPAUDIOWAVE      pSons[];
 extern unsigned int     iFlagBruitages[];
 extern unsigned int     iBruitagesVoix;                        //nombre de voix pour les bruitages
 extern unsigned int     iTailleSons;                           //taille des sons
-
 #ifdef DEVELOPPEMENT2
 int                     iBruitage = 0;                         //numero d'un bruitage a jouer
 #endif
@@ -92,12 +91,11 @@ char _etbfonte1::pTexteAbout[]=
   "*                              *@* "\
   POWERMANGA_VERSION\
   "*@*                LINUX VERSION *@"\
-  "* (c) 1998-2003 TLK-GAMES      *@"\
+  "* (c) 1998-2004 TLK-GAMES      *@"\
   "*                              *@"\
   "* LINUX.TLK.FR                 *@"\
   "*                              *@"\
   "* BY :                         *@"\
-  "*                              *@"\
   "* ANDRE MAJOREL                *@"\
   "* BRUNO ETHVIGNOT              *@"\
   "* DAVID IGREJA                 *@"\
@@ -106,8 +104,9 @@ char _etbfonte1::pTexteAbout[]=
   "* GUILLAUME COTTENCEAU         *@"\
   "* JEAN MICHEL MARTIN DE SANTERO*@"\
   "* LAURENT DUPERVAL             *@"\
+  "* PATRICE DUHAMEL              *@"\
   "* MICHEL DOGNIAUX              *@"\
-  "* SAM HOCEVAR                  *@"\
+  "* SAMUEL HOCEVAR               *@"\
   "*                              *@"\
   "*  > PRESS CTRL-A TO CANCEL <  *@"\
   "********************************@"
@@ -205,14 +204,14 @@ _etbfonte1::_etbfonte1()
   iTempoClavier = 0;
   num_level_sauve = 0;
   allez_gardien = 14;
+  pFonte = (unsigned char *)NULL;
 }
 
 // destructeur *****************************************************************
 _etbfonte1::~_etbfonte1()
 {
   if(pFonte != 0)
-  {
-    libereMemoire((char *)pFonte);
+  { libereMemoire((char *)pFonte);
     pFonte = 0;
   }
 }
