@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2003 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "explosionExecution.cpp"
 // created      : ?
-// updates      : 2002-08-02
+// updates      : 2003-07-20
 //-----------------------------------------------------------------------------
 // functions : void   explosionExecution()
 //             void   Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl )
@@ -47,7 +47,7 @@ extern unsigned int     iCompteurGlobal;                       //global counter
 //------------------------------------------------------------------------------
 void explosionExecution()
 {
-  int                     i;
+  int i;
 
   //gestion des explosions (grosses, moyennes, petites, et speciales) -----------
   for(i = 0; i < nbr_exps; i++)
@@ -108,12 +108,10 @@ void explosionExecution()
 //------------------------------------------------------------------------------
 void Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl)
 {
-  int                     k, new_xpl;
-
-
+  int k, new_xpl;
   switch (type)
   {
-    //explostion de taille 32*32 ---------------------------------------------------
+    //explosion de taille 32*32 ------------------------------------------------
     case 0:
       new_xpl = New_Element_Exp();                             //demande un nouvel element 'xpl' 
       if(new_xpl >= 0)                                         //nouvel element trouve ?
@@ -136,7 +134,7 @@ void Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl)
       }
       break;
 
-      //explosion de taille 64*64 ----------------------------------------------------
+      //explosion de taille 64*64 ----------------------------------------------
     case 1:
       new_xpl = New_Element_Exp();                             //demande un nouvel element 'xpl' 
       if(new_xpl >= 0)                                         //nouvel element trouve ?
@@ -160,23 +158,21 @@ void Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl)
       break;
       //explosion de taille 16*16 ----------------------------------------------------
     case 2:
-      new_xpl = New_Element_Exp();                             //demande un nouvel element 'xpl' 
-      if(new_xpl >= 0)                                         //nouvel element trouve ?
-      {
-        xpl[new_xpl].img_act = 0;                              //commence image 0 
-        xpl[new_xpl].nbr_tot_vbl = 1;                          //vitesse d'animation
-        xpl[new_xpl].nbr_vbl_act = 0;                          //raz le compteur d'animation
+      new_xpl = New_Element_Exp();    //demande un nouvel element 'xpl' 
+      if(new_xpl >= 0)                //nouvel element trouve ?
+      { xpl[new_xpl].img_act = 0;     //commence image 0 
+        xpl[new_xpl].nbr_tot_vbl = 1; //vitesse d'animation
+        xpl[new_xpl].nbr_vbl_act = 0; //raz compteur d'animation
         for(k = 0; k < NBR_IMAGES_EXP; k++)
-        {
-          xpl[new_xpl].img[k] = (image *) & explo[0][k];
+        { xpl[new_xpl].img[k] = (image *) & explo[0][k];
         }
-        xpl[new_xpl].coor_x = c_x - 4;                         //abscisse d'affichage
-        xpl[new_xpl].coor_y = c_y - 4;                         //ordonnee d'affichage
-        xpl[new_xpl].vitesse = vitesse;                        //vitesse de deplacement
+        xpl[new_xpl].coor_x = c_x - 4;  //abscisse
+        xpl[new_xpl].coor_y = c_y - 4;  //ordonnee
+        xpl[new_xpl].vitesse = vitesse; //vitesse deplacement
         xpl[new_xpl].img_angle = 8;
-        xpl[new_xpl].nbr_vbl_av_exp = nbr_vbl;                 //duree d'affichage de l'explosion
+        xpl[new_xpl].nbr_vbl_av_exp = nbr_vbl; //duree d'affichage explosion
 #ifdef UTILISE_SEAL
-        seal_joue(XPLOA1 + (iCompteurGlobal & 3));             //joue explosion un son avec seal
+        seal_joue(XPLOA1 + (iCompteurGlobal & 3));  //son explosion
 #endif
       }
       break;
@@ -184,13 +180,11 @@ void Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl)
     case 3:
       new_xpl = New_Element_Exp();                             //demande un nouvel element 'xpl' 
       if(new_xpl >= 0)                                         //nouvel element trouve ?
-      {
-        xpl[new_xpl].img_act = 0;                              //commence image 0 
+      { xpl[new_xpl].img_act = 0;                              //commence image 0 
         xpl[new_xpl].nbr_tot_vbl = 6;                          //vitesse d'animation
         xpl[new_xpl].nbr_vbl_act = 0;                          //raz le compteur d'animation
         for(k = 0; k < NBR_ETOILES; k++)
-        {
-          xpl[new_xpl].img[k] = (image *) & star_field[PLAYERSTAR][k];
+        { xpl[new_xpl].img[k] = (image *) & star_field[PLAYERSTAR][k];
         }
         xpl[new_xpl].coor_x = c_x;                             //abscisse d'affichage
         xpl[new_xpl].coor_y = c_y;                             //ordonnee d'affichage
@@ -202,6 +196,34 @@ void Add_Explosion(float c_x, float c_y, float vitesse, int type, int nbr_vbl)
   }
 }
 
+//------------------------------------------------------------------------------
+// ajoute une explosion a la liste (routine special gardien)
+// input => c_x : abscisse de l'explosion
+//       => c_y : ordonnee de l'explosion
+//------------------------------------------------------------------------------
+void Add_Explosion_Guard(float c_x, float c_y)
+{
+  int k, new_xpl;
+  new_xpl = New_Element_Exp();    //demande un nouvel element 'xpl' 
+  if(new_xpl >= 0)                //nouvel element trouve ?
+  { xpl[new_xpl].img_act = 0;     //commence image 0 
+    xpl[new_xpl].nbr_tot_vbl = 1; //vitesse d'animation
+    xpl[new_xpl].nbr_vbl_act = 0; //raz compteur d'animation
+    for(k = 0; k < NBR_IMAGES_EXP; k++)
+      xpl[new_xpl].img[k] = (image *) & explo[0][k];
+    xpl[new_xpl].coor_x = c_x - 4;  //abscisse
+    xpl[new_xpl].coor_y = c_y - 4;  //ordonnee
+    xpl[new_xpl].vitesse = -.5;     //vitesse deplacement
+    xpl[new_xpl].img_angle = 8;
+    xpl[new_xpl].nbr_vbl_av_exp = 0; //duree d'affichage explosion
+#ifdef UTILISE_SEAL
+    if(!(rand() % 8))
+    { seal_joue(XPLOA1 + (iCompteurGlobal & 3));  //son explosion
+    }
+#endif
+  }
+}
+
 //------------------------------------------------------------------------------
 // ajouter des eclat(s) a la liste
 // input => c_x     : abscisse de l'explosion
