@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2002 TLK Games all rights reserved
+// copyright (c) 1998-2003 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "init_game.cpp"
 // created      : ?
-// updates      : 2002-08-02
+// updates      : 2003-07-20
 //-----------------------------------------------------------------------------
 // functions    :  int   inits_game()
 //                 int   etb_read_image(char* _pNomFichier, image* _pImage, unsigned int _iNombreType, unsigned _iNombreImage) ;
@@ -112,20 +112,15 @@ int                     load_options();
 //------------------------------------------------------------------------------
 int inits_game()
 {
-  int                     i, j;
+  int i, j;
   iErreurInitialisation = 0;
-#ifdef UTILISE_SEAL
-  if(seal_init() == FALSE)
-    return 0;
-#endif
   chaine = reserveMemoire(2000);                               //zone pour les chaines de caracteres
   if(!chaine)
-  {
-    afficheErreur("'chaine' out of memory", "inits_game.cpp/inits_game()");
+  { afficheErreur("'chaine' out of memory", "inits_game.cpp/inits_game()");
     return 0;
   }
 
-  //chargement des fichiers -----------------------------------------------------
+  //chargement des fichiers ----------------------------------------------------
   if(!charge_palette("graphics/image.pal")) return 0;
   if(!charge_ennemis()) return 0;
   if(!etb_read_image("graphics/tirs.spr",     &fire[0][0], MAX_TYP_OF_TIR, NBR_IMAGES_TIR))  return 0;              //996131 octets
@@ -144,41 +139,35 @@ int inits_game()
   if(!charge_etoiles()) return 0;
   initialise_etoiles();                                                                                             //initialise le champ d'etoile / initialize starfield
 
-  //initialisation des adresse memoires utilisees par les gardiens ---------------
+  //initialisation des adresse memoires utilisees par les gardiens -------------
   for(i = 0; i < NBR_ANIM_GARDIAN; i++)
-  {
-    for(j = 0; j < NBR_IMAGES_NMI_S; j++)
-    {
-      gardi[i][j].img = 0;
+  { for(j = 0; j < NBR_IMAGES_NMI_S; j++)
+    { gardi[i][j].img = 0;
       gardi[i][j].compress = 0;
     }
   }
-  //initialisation de la memoire utilisee par les images des meteorites ----------
+  //initialisation de la memoire utilisee par les images des meteorites --------
   for(i = 0; i < (MAX_TYP_OF_METEOR); i++)
-  {
-    for(j = 0; j < NBR_IMAGES_METEOR; j++)
-    {
-      meteo[i][j].img = 0;
+  { for(j = 0; j < NBR_IMAGES_METEOR; j++)
+    { meteo[i][j].img = 0;
       meteo[i][j].compress = 0;
     }
   }
 
-  //initialisation du tableau 'fnt_scr' -----------------------------------------
+  //initialisation du tableau 'fnt_scr' ----------------------------------------
   for(i = 0; i < NBR_FNT_SCROLL_MAX; i++)
-  {
-    fnt_scr[i].next_object = NBR_FNT_SCROLL_MAX;               //objet actuel est libre
-    fnt_scr[i].prev_object = NBR_FNT_SCROLL_MAX;               //objet actuel est libre
+  { fnt_scr[i].next_object = NBR_FNT_SCROLL_MAX; //objet actuel est libre
+    fnt_scr[i].prev_object = NBR_FNT_SCROLL_MAX; //objet actuel est libre
     liste_fnt_scroll[i] = 0;
   }
   nbr_fnt_scroll = 0;
 
-  //initialisation du tableau 'tirs' ainsi que du nombre de tirs ----------------
-  Init_Tab_Tirs();                                             // "powermanga sub2.cpp"
+  //initialisation du tableau 'tirs' ainsi que du nombre de tirs ---------------
+  Init_Tab_Tirs();  // "powermanga sub2.cpp"
 
-  //initialisation des valeurs utilisees pour l'affichage des options -----------
+  //initialisation des valeurs utilisees pour l'affichage des options ----------
   for(i = 0; i < MAX_TYP_OF_OPTIONS; i++)
-  {
-    aff_option[i].nbr_tot_vbl = 1000;
+  { aff_option[i].nbr_tot_vbl = 1000;
     aff_option[i].add_vbl = 550;
     aff_option[i].img_act = 0;
     aff_option[i].nbr_vbl_act = 0;
