@@ -3,7 +3,7 @@
 //-----------------------------------------------------------------------------
 // file         : "linuxroutines.cpp"
 // created      : 1999-08-19
-// updates      : 2003-07-01
+// updates      : 2004-08-01 
 //------------------------------------------------------------------------------
 // functions    :  int              mem_initialise(unsigned int _iNombreZones)
 //                 char*            reserveMemoire(unsigned int _iTailleMemoire)
@@ -40,19 +40,22 @@
 // Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 //*****************************************************************************
+
 #include "powermanga.hpp"
 #include <errno.h>
+
+#ifndef SDL_TLK
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <unistd.h>
+#endif
+
 //..............................................................................
 extern unsigned int     iVerbeux;                              //1=affiche les arguments / 1=verbose mode
 
 //gestion de la memoire .........................................................
 typedef struct
-{
-  char                   *pMemoire;                            //pointeur sur la zone memoire  / pointer to memory zone
-  int                     iTailleMemoire;                      //taille de la zone en octets           / size of memory zone in bytes
+{ char *pMemoire;                                              //pointeur sur la zone memoire / pointer to memory zone
+  int   iTailleMemoire;                                         //taille de la zone en octets / size of memory zone in bytes
 }
 sListeMemoire;
 char                   *pZoneListeMemoire;
@@ -65,18 +68,26 @@ unsigned int            iOctetsTotal;                          //taille prise en
 unsigned int            iNombreZonesMax;                       //nombre maximum de zones reserves
 
 //..............................................................................
-static struct timeval   time_begin;
 unsigned int            iCompteurBoucle;
+#ifdef SDL_TLK 
+Uint32                  time_begin;
+Uint32                  temps_actuel;
+Uint32                  temps_sauve;
+Uint32                  temps_actuel2;
+Uint32                  temps_sauve2;
+#else
+static struct timeval   time_begin;
 static struct timeval   temps_actuel;
 static struct timeval   temps_sauve;
 static struct timeval   temps_actuel2;
 static struct timeval   temps_sauve2;
+#endif
 
 //..............................................................................
 short                   litMot16bitsBig(short *_pMem);
 unsigned short          litMot16bits(unsigned short *_pMem);
 extern const char       nomprefix[];
-
+extern unsigned int     iFrame3; 
 //------------------------------------------------------------------------------
 // initialise la liste memoire / initialise memory table
 // input =>  _iNombreZones : nombre de zones memoire possibles au maximum / number maximum of memory zone
@@ -84,7 +95,7 @@ extern const char       nomprefix[];
 //------------------------------------------------------------------------------
 int mem_initialise(unsigned int _iNombreZones)
 {
-  unsigned int            _iIndex;
+  unsigned int _iIndex;
   iNombreZones = 0;                                            // nombre de zones reservees a zero
   pZoneListeMemoire = 0;
   iNombreZonesMaximum = _iNombreZones;                         // nombre maximum de zones pouvant etre reservees 
@@ -207,13 +218,13 @@ void mem_libereTous()
   sListeMemoire *_pListeMem = pZoneListeBase;
 #ifdef _VERBEUX_
   if(iVerbeux > 0)
-    fprintf(stderr, "mem_libereTous() : maximum of memory which were allocated during the game : %i\n", iNombreZonesMax);
+    fprintf(stdout, "> linuxroutines.cpp/mem_libereTous(): maximum of memory which were allocated during the game : %i\n", iNombreZonesMax);
 #endif
   if(iNombreZones >0)
   { 
 #ifdef _VERBEUX_
     if(iVerbeux > 0)
-      fprintf(stderr, "mem_libereTous() : %i zones were not released.\n", iNombreZones);
+      fprintf(stdout, "> linuxroutines.cpp/mem_libereTous() : %i zones were not released.\n", iNombreZones);
 #endif
     for(_iCompteur = 0; _iCompteur < iNombreZones; _iCompteur++, _pListeMem++)
     { _pMemoire = _pListeMem->pMemoire;
@@ -294,7 +305,13 @@ sDescriptionGfx *load_pcx(char *_pNomFichier)
   libereMemoire((char *)_pFichier);
 #ifdef _VERBEUX_
   if(iVerbeux > 0)
-    printf ("linuxroutines.cpp/load_pcx() : file \"%s\" (height=%i / width=%i\n / size=%i) was decompressed\n", _pNomFichier, _iLarge, _iHaut, _pDescripGfx->iTaille);
+    fprintf (
+      stdout,
+      "> linuxroutines.cpp/load_pcx(): \"%s\"; height=%i; width=%i; size=%i\n",
+      _pNomFichier,
+      _iLarge,
+      _iHaut,
+      _pDescripGfx->iTaille);
 #endif
   return _pDescripGfx;
 }
@@ -306,14 +323,8 @@ sDescriptionGfx *load_pcx(char *_pNomFichier)
 //------------------------------------------------------------------------------
 unsigned int littleWord(char *_pMem)
 {
-  unsigned short         *t = (unsigned short *)_pMem;
+  unsigned short *t = (unsigned short *)_pMem;
   return *t;
-  //unsigned int            _iValeur = 0;
-  //unsigned char          *_pMemoire = (unsigned char *)_pMem;
-  //_iValeur = _pMemoire[1];                                     //lit du little endian pour un powerpc
-  //_iValeur <<= 8;
-  //_iValeur += _pMemoire[0];
-  //return (_iValeur);
 }
 
 //------------------------------------------------------------------------------
@@ -323,8 +334,8 @@ unsigned int littleWord(char *_pMem)
 //------------------------------------------------------------------------------
 short litMot16bits(short *_pMem)
 {
-  short                   _iValeur = 0;
-  unsigned char          *_pMemoire = (unsigned char *)_pMem;
+  short  _iValeur = 0;
+  unsigned char  *_pMemoire = (unsigned char *)_pMem;
   _iValeur = _pMemoire[1];                                     //lit du little endian pour un powerpc
   _iValeur <<= 8;
   _iValeur += _pMemoire[0];
@@ -432,21 +443,28 @@ static const char      *data_directories[]=
   0                                                            // Special value meaning "$(PREFIX)/share/games/powermanga/"
                                                                // Also marks end of list
 };
+static char pathstring[256];
+
 char *locate_data_file(const char *const name)
 {
+  
+  for(int i = 0; i < 256; i++)
+	pathstring[i] = 0;
+	
   if(name == 0) return 0;
   if(*name == '/') return strdup(name);                        // Guillaume Cottenceau (2001-03-15) replace "return 0;" by "strdup(name);"
                                                                // En effet, nous sommes dans le cas ou le programme recherche dans /usr/share/games/powermanga
   for(const char **p = data_directories;; p++)
-  { char                   *pathname;
+  { char *pathname;
     if(*p == 0)
-    { const char             *subdir = "/share/games/powermanga/";
-      pathname=(char *)malloc(strlen(nomprefix) + strlen(subdir) + strlen(name) + 1);
+    { const char *subdir = "/share/games/powermanga/";
+      pathname = &pathstring[0];
+      /*pathname=(char *)malloc(strlen(nomprefix) + strlen(subdir) + strlen(name) + 1);
       if(pathname == 0)
       { fflush(stdout);
         fprintf(stderr, "powermanga: not enough memory\n");
         return 0;
-      }
+      }*/
       strcpy(pathname, nomprefix);
       strcat(pathname, subdir);
       strcat(pathname, name);
@@ -456,12 +474,14 @@ char *locate_data_file(const char *const name)
       static const char      *home_dir = &bogus;
       if(home_dir == &bogus) home_dir = getenv("HOME");
       if(home_dir == 0) continue;                             // $HOME not set. Skip this directory.
-      pathname = (char *)malloc(strlen(home_dir) + 1 + strlen(*p + 1) + 1 + strlen(name) + 1);
+      pathname = &pathstring[0];
+      
+      /*pathname = (char *)malloc(strlen(home_dir) + 1 + strlen(*p + 1) + 1 + strlen(name) + 1);
       if(pathname == 0)
       { fflush(stdout);
         fprintf(stderr, "powermanga: not enough memory\n");
         return 0;
-      }
+      }*/
       strcpy(pathname, home_dir);
       strcat(pathname, *p + 1);
       strcat(pathname, "/");
@@ -469,21 +489,28 @@ char *locate_data_file(const char *const name)
     }
     else
     {
-      pathname = (char *)malloc(strlen(*p) + 1 + strlen(name) + 1);
+      pathname = &pathstring[0];
+      /*pathname = (char *)malloc(strlen(*p) + 1 + strlen(name) + 1);
       if(pathname == 0)
       { fflush(stdout);
         fprintf(stderr, "powermanga: not enough memory\n");
         return 0;
-      }
+      }*/
       strcpy(pathname, *p);
       strcat(pathname, "/");
       strcat(pathname, name);
     }
     //puts(pathname);  // DEBUG
-    struct stat             s;
+#ifdef WIN32
+    struct _stat s;
+    if(_stat(pathname, &s) == 0 && !_S_ISDIR(s.st_mode))
+      return pathname;
+#else
+    struct stat s;
     if(stat(pathname, &s) == 0 && !S_ISDIR(s.st_mode))
       return pathname;
-    free(pathname);
+#endif
+    //free(pathname);
     if(*p == 0) break;
   }
   return 0;                                                    // Not found.
@@ -504,9 +531,9 @@ char *chargeFichier(char *_pNomFichier)
 }
 
 //------------------------------------------------------------------------------
-// load a file in memory / charge un fichier en memoire
-// input => _pNomFichier : nom du fichier / filename
-// sortie <= _pMemoire   : zone memoire ou est stockee le fichier (0=erreur)
+// load a file in memory 
+// input => _pNomFichier : filename
+// sortie <= _pMemoire   : ptr/integer 
 //------------------------------------------------------------------------------
 char *chargeFichier(char *_pNomFichier, unsigned int *pTaille)
 {
@@ -518,16 +545,20 @@ char *chargeFichier(char *_pNomFichier, unsigned int *pTaille)
   { printf("linuxroutines/chargeFichier() : can't locate file : %s\n\n", _pNomFichier);
     return 0;
   }
-  _iHandle = open(pathname, O_RDONLY, 0);                      //ouvre le fichier
+#ifdef WIN32
+  _iHandle = open(pathname, O_RDONLY | O_BINARY, 0); 
+#else
+  _iHandle = open(pathname, O_RDONLY, 0); 
+#endif
   if(_iHandle == -1)
   { printf("linuxroutines/chargeFichier() : can't open file : %s (%s)\n\n", pathname, strerror(errno));
-    free(pathname);
+    //free(pathname);
     return 0;
   }
   if(fstat(_iHandle, &sDescriptionFichier))
   { printf("linuxroutines/chargeFichier() : can't stat file : %s (%s)\n\n", pathname, strerror(errno));
     close(_iHandle);
-    free(pathname);
+    //free(pathname);
     return 0;
   }
   (*pTaille) = sDescriptionFichier.st_size;                    //sauve taille
@@ -535,14 +566,14 @@ char *chargeFichier(char *_pNomFichier, unsigned int *pTaille)
   if(!_pMemoire)
   { printf("linuxroutines/chargeFichier() %s : out of memory\n\n", pathname);
     close(_iHandle);
-    free(pathname);
+    //free(pathname);
     return 0;
   }
   if(read(_iHandle, _pMemoire, sDescriptionFichier.st_size) != sDescriptionFichier.st_size)
   { libereMemoire(_pMemoire);
     printf("linuxroutines/chargeFichier() can't read file %s (%s)\n\n", pathname, strerror(errno));
     close(_iHandle);
-    free(pathname);
+    //free(pathname);
     return 0;
   }
   close(_iHandle);
@@ -550,7 +581,7 @@ char *chargeFichier(char *_pNomFichier, unsigned int *pTaille)
   if(iVerbeux > 1)
     printf("linuxroutines/chargeFichier : file %s was loaded in memory\n", pathname);
 #endif
-  free(pathname);
+  //free(pathname);
   return _pMemoire;
 }
 
@@ -569,29 +600,33 @@ int chargeFichier(char *_pNomFichier, char *_pMemoire)
   { printf("linuxroutines/chargeFichier() : can't locate file : %s\n\n", _pNomFichier);
     return 0;
   }
-  _iHandle = open(pathname, O_RDONLY, 0);                      // open file / ouvre le fichier
+#ifdef WIN32
+  _iHandle = open(pathname, O_RDONLY | O_BINARY, 0); 
+#else
+  _iHandle = open(pathname, O_RDONLY, 0); 
+#endif
   if(_iHandle == -1)
   { printf ("linuxroutines.cpp/chargeFichier() : can't open file : %s (%s)\n\n", pathname, strerror(errno));
-    free(pathname);
+    //free(pathname);
     return 0;
   }
   if(fstat(_iHandle, &sDescriptionFichier))
   { printf ("linuxroutines.cpp/chargeFichier() : can't stat file : %s (%s)\n\n", pathname, strerror(errno));
     close(_iHandle);
-    free(pathname);
+    //free(pathname);
     return 0;
   }
   if(read(_iHandle, _pMemoire, sDescriptionFichier.st_size) != sDescriptionFichier.st_size)
   { printf("linuxroutines.cpp/chargeFichier() can't read file %s (%s)\n\n", pathname, strerror(errno));
     close(_iHandle);
-    free(pathname);
+    //free(pathname);
     return 0;
   }
   close(_iHandle);
 #ifdef _VERBEUX_
   if(iVerbeux > 1) printf("linuxroutines/chargeFichier : file %s was loaded in memory\n", pathname);
 #endif
-  free(pathname);
+  //free(pathname);
   return 1;
 }
 
@@ -600,9 +635,15 @@ int chargeFichier(char *_pNomFichier, char *_pMemoire)
 //------------------------------------------------------------------------------
 void fps_init()
 {
+#ifdef SDL_TLK 
+  time_begin = SDL_GetTicks();
+  temps_sauve = SDL_GetTicks();
+  temps_sauve2 = SDL_GetTicks();
+#else
   gettimeofday(&time_begin, NULL);
   gettimeofday(&temps_sauve, NULL);
   gettimeofday(&temps_sauve2, NULL);
+#endif
   iCompteurBoucle = 0;
 }
 
@@ -611,6 +652,20 @@ void fps_init()
 //------------------------------------------------------------------------------
 void fps_affiche()
 {
+  
+#ifdef SDL_TLK
+  double fps;
+  unsigned long duration;
+  Sint32 time_end; 
+  time_end = SDL_GetTicks();
+  duration = time_end - time_begin;
+  fps = (1000.0 * iCompteurBoucle) / duration;
+  if(iVerbeux > 0)
+  { printf("> linuxroutines.cpp/number of loops : %i\n", iCompteurBoucle);
+    printf("> linuxroutines.cpp/running time    : %li\n", duration);
+    printf("> linuxroutines.cpp/fps_affiche()   : frames per seconde : %g \n", fps);
+  }
+#else  
   struct utsname          kernel;
   struct stat             statmem;
   unsigned long           duration;
@@ -671,6 +726,7 @@ void fps_affiche()
     printf("frames per seconde : %g \n", fps);
     //printf ( "Compilateur      : %s\n" , COMPILO );
   }
+#endif
 }
 
 //------------------------------------------------------------------------------
@@ -730,22 +786,43 @@ void afficheErreur(char *_pErreur1, char *_pErreur2, int _iErreur)
 //------------------------------------------------------------------------------
 int synchro_processusPause(int _iTemps)
 {
-  struct timeval          temps;
+#ifdef SDL_TLK 
+  if(_iTemps > (int)iFrame3)
+    _iTemps = iFrame3;
+  if(_iTemps > 0)
+    SDL_Delay(_iTemps);
+  return (_iTemps > 0 ? _iTemps : 0);
+#else
+  struct timeval temps;
+  if(_iTemps > (int)iFrame3)
+    _iTemps = iFrame3;
   if(_iTemps > 0)
   { temps.tv_usec = _iTemps % (unsigned long)1000000;
     temps.tv_sec = _iTemps / (unsigned long)1000000;
-    select(0, NULL, NULL, NULL, &temps);                       //sleep for a time interval
+    //sleep for a time interval
+    select(0, NULL, NULL, NULL, &temps);
   }
   return (_iTemps > 0 ? _iTemps : 0);
+#endif
 }
 
+#ifdef SDL_TLK
+int synchro_CalculDifference()
+{
+  int _iDifference;
+  temps_actuel = SDL_GetTicks();
+  _iDifference = temps_actuel - temps_sauve;
+  temps_sauve = temps_actuel;
+  return _iDifference;
+}
+#else
 //------------------------------------------------------------------------------
 // calcul la difference entre deux heure differentes
 // sortie <= : _iDifference
 //------------------------------------------------------------------------------
 int synchro_CalculDifference()
 {
-  int                     _iDifference;
+  int _iDifference;
   gettimeofday(&temps_actuel, NULL);
   _iDifference = (1000000 * (temps_actuel.tv_sec - temps_sauve.tv_sec)) + (temps_actuel.tv_usec - temps_sauve.tv_usec);
   temps_sauve = temps_actuel;
@@ -758,9 +835,10 @@ int synchro_CalculDifference()
 //------------------------------------------------------------------------------
 int synchro_CalculDifference2()
 {
-  int                     _iDifference;
+  int _iDifference;
   gettimeofday(&temps_actuel2, NULL);
   _iDifference = (1000000 * (temps_actuel2.tv_sec - temps_sauve2.tv_sec)) + (temps_actuel2.tv_usec - temps_sauve2.tv_usec);
   temps_sauve2 = temps_actuel2;
   return _iDifference;
 }
+#endif
