@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2003 TLK Games all rights reserved
+// copyright (c) 1998-2004 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "powermanga.cpp"
 // created      : ?
-// updates      : 2002-08-02
+// updates      : 2004-08-01
 //-----------------------------------------------------------------------------
 // This program is free software; you can redistribute it and/or modify it under
 // the terms of the GNU General Public License as published by the Free Software
@@ -22,7 +22,9 @@
 //*****************************************************************************
 //..............................................................................
 #include "powermanga.hpp"
+
 //..............................................................................
+extern int              fullscreen;                            // 1=full screen (use dga or real full screen with SDL)
 unsigned int            iJoueIntro = 1;                        //1=start anim / 2= end anom 
 unsigned int            iCodeTouche = 0;                       //code key pressed / code touche pressee
 unsigned int            iBoutonFeu = 0;                        //1=bouton de la manette de jeu enfonce
@@ -39,7 +41,7 @@ int                     iNumeroGardien;
 void                    _execute_congra(int);
 int                     iErreurInitialisation;                 //1=erreur a l'initialisation
 extern unsigned int     iOctetsParPixel;                       //nombre d'octets par pixels (1=256 couleurs / 2=65536 couleurs)
-_etbfonte1             *pEtbfonte1 = new _etbfonte1();         //(ETB)objet cpp geran affichage caracteres 8x8
+extern _etbfonte1      *pEtbfonte1;                            //object handle 8x8 chars (about CTRL + A)
 
 //..............................................................................
 // Variables utilisees pour la gestion generale du jeu *************************
@@ -126,8 +128,8 @@ float                   vit_star_field = 2.0;                  //vitesse du cham
 vaisseau_nmi            ve[MAX_NMI_ON_SCREEN];                 // Dclaration de la structure des vaisseaux ennemis.
 int                     liste_ve[MAX_NMI_ON_SCREEN];           // liste de tous les vaisseaux ennemis a gerer
 int                     cmpt_nmis;                             //compteur nombre d'ennemis
-short                   nbr_nmis = 0;                          // Indique le nombre d'enemis actuellement grs.
-int                     new_ve;                                // Indique l'indice du tableau corespondant  un nouvel objet 've'.
+short                   nbr_nmis = 0;                          //aliens current number
+int                     new_ve;                                //Indique l'indice du tableau corespondant  un nouvel objet 've'.
 explosion               xpl[MAX_NMI_ON_SCREEN];                //structure utilisee par les explosions
 int                     liste_xpl[MAX_NMI_ON_SCREEN];          //liste de tous les 'xpl' geres
 int                     cmpt_exps;                             //compteur du nombre d'explosions
@@ -206,26 +208,25 @@ short						        cercle_px[] = {30,29,29,29,28,27,26,25,24,22,21,19,17,15,13,1
 short						        cercle_py[] = {0,2,4,7,9,11,13,15,17,19,21,22,24,25,26,27,28,29,29,29,30,29,29,29,28,27,26,25,24,22,21,19,17,15,13,11,9,7,4,2,0,-2,-4,-7,-9,-11,-13,-15,-17,-19,-21,-22,-24,-25,-26,-27,-28,-29,-29,-29,-30,-29,-29,-29,-28,-27,-26,-25,-24,-22,-21,-19,-17,-15,-13,-11,-9,-7,-4,-2};
 
 //******************************************************************************
-// "upDateFrame" : boucle principale du jeu / the main loop of  game
+// "upDateFrame" : the main loop of game / boucle principale du jeu
 //******************************************************************************
 int UpdateFrame()
 {                                                              //static int                    i, j, k, l, m, n, o ; // variables utilisees pour les boucles
-  static int              i;
+  static int i;
 
 //..............................................................................
 #ifdef DEVELOPPEMENT
-  static bool             grid_editor = 0;                     //1=editeur de grille en cours
+  static bool  grid_editor = 0; //1=editeur de grille en cours
 #endif
 //..............................................................................
-  iCompteurGlobal++;                                           // compteur global 
+  iCompteurGlobal++; // global counter / compteur global 
   ce_vais_act = 0;
 
   //joue les animations d'etienne ----------------------------------------------
   if(iJoueIntro != 0)
   {
     if(!joueAnimation())
-    {
-      afficheErreur("joueAnimation() failed !",
+    { afficheErreur("joueAnimation() failed !",
                     "powermanaga.cpp/UpdateFrame()");
       return 0;
     }
@@ -233,16 +234,16 @@ int UpdateFrame()
       return 1;
   }
 
-  //efface l'ecran logique -------------------------------------------------------
+  //efface l'ecran logique -----------------------------------------------------
   raz_ecran(ecran_ram + (BANDE_DE_CLIP * LARG_ECR_RAM_TOT * iOctetsParPixel) +
             (BANDE_DE_CLIP * iOctetsParPixel),
             (LARG_ECR_RAM * iOctetsParPixel) >> 2, HAUT_ECR_RAM,
             (LARG_ECR_RAM_TOT - LARG_ECR_RAM) * iOctetsParPixel);
 
-  //restauration de l'energie du vaisseau du joueur ------------------------------
+  //restauration de l'energie du vaisseau du joueur ----------------------------
   vaisseau_restaure();
 
-  //editeurs de "grilles" et de "courbes" ----------------------------------------
+  //editeurs de "grilles" et de "courbes" --------------------------------------
 #ifdef DEVELOPPEMENT
   if(grid_editor || curv_editor)
   {
@@ -254,42 +255,43 @@ int UpdateFrame()
   else
 #endif
 
-  //routines du jeu ******************************************************************
-  {
-    if(!player_pause && etat_menu == MENU_OFF && _score::getActionExecution() == 0)     //pause inactive et menu inactif ?
-    {
-      grille_execution();                                      //phase 2 : execution des "grilles" de vaisseaux
-      courbe_execution();                                      //phase 1 : execution des "courbes" de vaisseaux
-      meteor_execution();                                      //phase 3 : execution des vagues de meteores 
+  //routines du jeu ************************************************************
+  { 
+    //pause inactive et menu inactif ?
+    if(!player_pause && etat_menu == MENU_OFF &&
+      _score::getActionExecution() == 0)
+    { grille_execution(); //phase 2 : execution des "grilles" de vaisseaux
+      courbe_execution(); //phase 1 : execution des "courbes" de vaisseaux
+      meteor_execution(); //phase 3 : execution des vagues de meteores 
     }
   }
 
-  //affiche le fond d'etoile defilant verticalemenent ----------------------------
+  //affiche le fond d'etoile defilant verticalemenent --------------------------
   afficheEtoiles();
 
-  //gestion des bonus -----------------------------------------------------------
+  //gestion des bonus ----------------------------------------------------------
   bonus_execution();
 
-  //gestion des canons & des boules autour du vaisseau du joueur ----------------
+  //gestion des canons & des boules autour du vaisseau du joueur ---------------
   if(!aff_game_over && _score::getActionExecution() == 0)
   {
     boule_execution();
     canon_execution();
   }
 
-  //gestion des ennemis ---------------------------------------------------------
+  //gestion des ennemis --------------------------------------------------------
   if(iCongratulation == 0)
-    ennemis_execution();                                       //gestion de tous les ennemis existants
+    ennemis_execution(); //gestion de tous les ennemis existants
   else
-    _execute_congra(iNumeroGardien);                           //routine special pour les "congratulations"
+    _execute_congra(iNumeroGardien); //routine special "congratulations"
 
-  //gestion de l'invincibilite du vaisseau --------------------------------------
+  //gestion de l'invincibilite du vaisseau -------------------------------------
   vaisseau_invincibilite();
 
-  //gestion de l'eclair (arme du vaisseau joueur) -------------------------------
+  //gestion de l'eclair (arme du vaisseau joueur) ------------------------------
   eclairExecution();
 
-  //affichage du vaisseau du joueur ---------------------------------------------
+  //affichage du vaisseau du joueur --------------------------------------------
   if(!aff_game_over && vj[J1].visible)
   {
     if(((short)vj[J1].spr.coor_y +
@@ -436,6 +438,7 @@ int UpdateFrame()
   if(game_over_player_one && !aff_game_over
      && _score::getActionExecution() == 0)
   {
+
     if(vj[J1].type_vaisseau != V1J)                            //le vaisseau n'est pas le premier vaisseau ?
     {
       vj[J1].type_vaisseau--;                                  //non, on regresse au vaisseau inferieur
@@ -467,6 +470,7 @@ int UpdateFrame()
     {
       _initialiseGameOver();                                   //sinon, c'etait le vaisseau 1, la partie est terminee
     }
+
   }
 
   //gestion de la barre d'energie du joueur --------------------------------------
@@ -549,6 +553,21 @@ int UpdateFrame()
   touch[47] = 0;
   touch[150] = 0;                                              //raz les touches de pause
 
+  
+#ifdef SDL_TLK
+  //if ((touch[39]) && (touche_ctrl))
+  if((touch[39]) && !_score::isInputName())
+  {  
+    if(fullscreen)
+      fullscreen = 0;
+    else
+      fullscreen = 1;
+    init_video_mode();
+  }
+  touch[39] = 0;
+#endif
+  
+  
   //clip la vitesse de deplacement du vaisseau du joueur -------------------------
   if(vj[J1].vitesse_x >= (float)vj[J1].vit_dep_vaisseau)       //depasse vitesse droite ?
   {
