@@ -1,9 +1,9 @@
 //*****************************************************************************
-// copyright (c) 1998-2003 TLK Games all rights reserved
+// copyright (c) 1998-2004 TLK Games all rights reserved
 //-----------------------------------------------------------------------------
 // file         : "score.cpp"
 // created      : 1998-06-29
-// updates      : 2003-04-07
+// updates      : 2004-08-01
 //-----------------------------------------------------------------------------
 // descriptions : manage scores / about / credits
 //-----------------------------------------------------------------------------
@@ -22,17 +22,23 @@
 // Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 //*****************************************************************************
+
 #include "powermanga.hpp"
 #include "score.hpp"
+
+#ifndef SDL_TLK
 #include <X11/keysym.h>
 #include <X11/keysymdef.h>
+#endif
+
 #include <errno.h>
+
 //..............................................................................
 extern const char      *nomfichierscore[] ;
 extern int              gameLevel;                             // Game difficulty (Laurent Duperval)
 //..............................................................................
 // Scores
-char                    _score::cScoresNoms[iNOMBRE_SCORES][4] =
+char _score::cScoresNoms[iNOMBRE_SCORES][4] =
 { {'T', 'L', 'K', 0},
   {'J', 'M', 'M', 0},
   {'E', 'T', 'B', 0},
@@ -86,7 +92,7 @@ char                   *_score::pTableAbout[] =
   "0ADDITIONAL", "0PROGRAMMING", "1LAURENT",     "1DUPERVAL", "@",
   "0ADDITIONAL", "0PROGRAMMING", "1SAMUEL",      "1HOCEVAR", "@",
   "0MUSICS BY",  "1MICHEL",      "1DOGNIAUX",    "@",
-  "0(c) 2003",   "1TLK",         "1GAMES",       "@",
+  "0(c) 2004",   "1TLK",         "1GAMES",       "@",
   "#"
 };
 // Variables declaree dans le fichier "powermanga.cpp"
@@ -109,22 +115,29 @@ int _score::getActionExecution()
 //******************************************************************************
 // Routine d'execution principale / main loop
 // input => _iFlag      : 0 main menu's disable (etat_menu==MENU_OFF)
-//                                                                      : 1 main menu's enable 
+//                      : 1 main menu's enable 
 //******************************************************************************
 void _score::execution(int _iFlag)
 {
   switch (iActionExecution)
-  {
-    case 1:                                                   // Game Over : le joueur a perdu son dernier vaisseau
+  { 
+    // "Game Over" : le joueur a perdu son dernier vaisseau
+    case 1:
       executeGameOver(_iFlag);
       break;
-    case 2:                                                   // affiche la table des scores : le joueur presse ESC dans le menu
+    
+    // affiche la table des scores : le joueur presse ESC dans le menu
+    case 2:
       executeTableScore(_iFlag);
       break;
-    case 3:                                                   // affiche les 'abouts' : qui fait quoi
+    
+    // affiche les 'abouts' : qui fait quoi
+    case 3:
       executeAbout(_iFlag);
       break;
-    case 4:                                                   // affiche le 'order' : comment commander
+    
+    // affiche le 'order' : comment commander
+    case 4:
       executeOrder(_iFlag);
       break;
 
@@ -186,6 +199,40 @@ int _score::setAction(int _iCodeAction)
   return 1;
 }
 
+//******************************************************************************
+// test if current input string
+//******************************************************************************
+int _score::isInputName()
+{ if(pChaineJoueur)
+    return 1;
+  else
+    return 0;
+}
+
+//******************************************************************************
+// release objects 
+//******************************************************************************
+void _score::destroy()
+{
+  //printf ("release objects \n");
+  if(pScoresObj)
+    delete [] pScoresObj;
+  if(pGame)
+    delete pGame;
+  if(pOver)
+    delete pOver;
+  if(pTxtChaines)
+    delete [] pTxtChaines; 
+  if(pTexteAbout)
+    delete [] pTexteAbout;
+  pGame = (_chaine *)NULL; 
+  pOver = (_chaine *)NULL; 
+  pScoresObj = (_chaine *)NULL;
+  pTxtChaines = NULL;
+  pTxtTableau = NULL;
+  pTexteAbout = NULL;
+}
+  
 //=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=
 // GAME OVER : initialize / initialise
 //  - trie des scores
@@ -291,27 +338,26 @@ int _score::affScores()
   int _iRetour = 0;
   int _iRotation = 1;
   unsigned int _iIndex1 = 0;
-
   for(_iIndex1 = 0; _iIndex1 < iNOMBRE_SCORES * 2; _iIndex1++)
-  {
-    _chaine                *_pChaine = &pScoresObj[_iIndex1];
-
+  { _chaine *_pChaine = &pScoresObj[_iIndex1];
     if(_pChaine->rotation1(2, 2, 0) == 0)
-      _iRotation = 0;                                          // _iRotation=1 alors rotation terminee
+      _iRotation = 0; // _iRotation=1 alors rotation terminee
   }
   // Gestion entree des caracteres + clignotement du curseur
   if(pChaineJoueur != 0 && _iRotation == 1)
-  {
-    _iRetour = pChaineJoueur->entreeClavier();
-    if(_iRetour == XK_Return)                                  //   RETURN pressed ? (ASCII=13) 
-    {
-      pChaineJoueur = (_chaine *) 0x0;
+  { _iRetour = pChaineJoueur->entreeClavier();
+    //   RETURN pressed ? (ASCII=13) 
+#ifdef SDL_TLK
+    if(_iRetour == SDLK_RETURN) 
+#else
+    if(_iRetour == XK_Return)
+#endif
+    { pChaineJoueur = (_chaine *) 0x0;
       sauveScores();
       _iRetour = 1;
     }
     else
-    {
-      _iRetour = 0;
+    { _iRetour = 0;
     }
   }
   afficheScores();
@@ -368,7 +414,11 @@ int _score::chargeScores()
   int _iHandle;
   struct stat sDescriptionFichier;
   char                   *_pMemoire = 0;
-  _iHandle = open(nomfichierscore[gameLevel], O_RDONLY, 0);		 //ouvre le fichier
+#ifdef WIN32
+  _iHandle = open(nomfichierscore[gameLevel], O_RDONLY | O_BINARY, 0);
+#else
+  _iHandle = open(nomfichierscore[gameLevel], O_RDONLY, 0);
+#endif
   if(_iHandle == -1)
   { printf("%s: %s\n", nomfichierscore[gameLevel], strerror(errno)) ;
   }
@@ -459,10 +509,10 @@ void _score::creeNouvelleTable()
 
 // Sauvegarde des scores  -----------------------------------------------------
 void _score::sauveScores()
-{                                                              //printf("%d %d \n", getgid(), getegid() ) ;
-  char                   *_pBuffer = new char[iTAILLEBUFFER];
-  char                   *_pBufferC = _pBuffer;
-  int                    *_pBufferL;
+{
+  char *_pBuffer = new char[iTAILLEBUFFER];
+  char *_pBufferC = _pBuffer;
+  int *_pBufferL;
   unsigned int _iIndex;
   unsigned int _iIndex2;
   for(_iIndex = 0; _iIndex < iNOMBRE_SCORES; _iIndex++)
@@ -476,18 +526,25 @@ void _score::sauveScores()
   int _iSomme = calculSomme((int *)_pBuffer, (iTAILLEBUFFER / 4) - 1);
   *_pBufferL = _iSomme;
   int _iHandle;
-  umask(0002);                                                                         // set umask so that files are group-writable
-  _iHandle = open(nomfichierscore[gameLevel] , O_WRONLY | O_CREAT, 00666);             //ouvre le fichier
+#ifdef WIN32
+  _umask(0002); //set umask so that files are group-writable
+#else
+  umask(0002);
+#endif
+  _iHandle = open(nomfichierscore[gameLevel] , O_WRONLY | O_CREAT, 00666); 
   if(_iHandle == -1)
-  { printf("%s: %s\n", nomfichierscore[gameLevel], strerror(errno)) ;
-  }
+    printf("%s: %s\n", nomfichierscore[gameLevel], strerror(errno));
   else
-  { write(_iHandle, _pBuffer, iTAILLEBUFFER);
+  {
+#ifdef WIN32	 
+    _write(_iHandle, _pBuffer, iTAILLEBUFFER);
+#else
+    write(_iHandle, _pBuffer, iTAILLEBUFFER);
+#endif
     if(close(_iHandle) != 0)
-    { printf("%s: %s\n", nomfichierscore[gameLevel], strerror(errno)) ;
-    }
+     printf("%s: %s\n", nomfichierscore[gameLevel], strerror(errno));
   }
-  delete _pBuffer;
+  delete [] _pBuffer;
 }
 
 // Calcul la somme d'auto-controle des scores ---------------------------------
@@ -972,30 +1029,23 @@ void _score::executeAbout(int _iFlag)
 //=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=!=
 int _score::creeOrder()
 {
-  char                   *_pTxt;
+  char *_pTxt;
   unsigned int _iIndex;
 
   if(pTxtChaines == 0x0)
     pTxtChaines = new _chaine[iTXT_NBRELIGNES];
   // Reserve le tableau de caractere
   if(pTxtTableau == 0x0)
-  {
-    pTxtTableau = new char[iTXT_NBRELIGNES * iTXT_NBRECOL];
-
+  { pTxtTableau = new char[iTXT_NBRELIGNES * iTXT_NBRECOL];
     _pTxt = pTxtTableau;
     for(_iIndex = 0; _iIndex < iTXT_NBRELIGNES * iTXT_NBRECOL; _iIndex++)
-    {
       _pTxt[_iIndex] = ' ';
-    }
-
   }
   int _iPosY = 128 + 7;
 
   _pTxt = pTxtTableau;
   for(_iIndex = 0; _iIndex < iTXT_NBRELIGNES; _iIndex++)
-  {
-    _chaine                *_oChaine = &pTxtChaines[_iIndex];
-
+  { _chaine *_oChaine = &pTxtChaines[_iIndex];
     _oChaine->initialise(_pTxt, iTXT_NBRECOL, 128, _iPosY, 16, 0);
     _iPosY += 16;
     _pTxt += iTXT_NBRECOL;
@@ -1018,8 +1068,8 @@ int _score::creeOrder()
 // iTXT_PAUSE : attente de la valeur suivante (1 a 32767)
 // iTXT_FIN : fin du fichier
 // sinon code clavier 
-// input => _iFlag      : 0 main menu's disable (etat_menu==MENU_OFF)
-//                                                                      : 1 main menu's enable 
+// input => _iFlag : 0 main menu's disable (etat_menu==MENU_OFF)
+//                 : 1 main menu's enable 
 //--**--**--**--**--**--**--**--**--**--**--**--**--**--**--**--**--**--**--**--
 void _score::executeOrder(int _iFlag)
 {
@@ -1091,6 +1141,51 @@ void _score::executeOrder(int _iFlag)
         else
         {
           _iCodeTouchePressee = _valeur;                       //force unsigned
+#ifdef SDL_TLK
+         
+/*       printf("XK_BackSpace=%x, XK_Delete=%x, XK_Right=%x, XK_Left=%x, XK_Up=%x, XK_Down=%x, XK_Return=%x, XK_F3=%x, XK_F4=%x, XK_F5=%x, XK_Shift_L=%x, XK_Shift_R=%x\n",
+         XK_BackSpace, XK_Delete, XK_Right, XK_Left, XK_Up, XK_Down, XK_Return, XK_F3, XK_F4, XK_F5, XK_Shift_L, XK_Shift_R);                   
+*/
+        switch(_iCodeTouchePressee)
+        { case 0xff08 : //XK_BackSpace
+            _iCodeTouchePressee = SDLK_BACKSPACE;
+            break;
+          case 0xffff: //XK_Delete
+            _iCodeTouchePressee = SDLK_DELETE;
+            break;
+          case 0xff53: //XK_Right
+            _iCodeTouchePressee = SDLK_RIGHT;
+            break;
+          case 0xff51: //XK_Left
+            _iCodeTouchePressee = SDLK_LEFT;
+            break;
+          case 0xff52: //XK_Up
+            _iCodeTouchePressee = SDLK_UP;
+            break;
+          case 0xff54: //XK_Down
+            _iCodeTouchePressee = SDLK_DOWN;
+            break;
+          case 0xff0d: //XK_Return
+            _iCodeTouchePressee = SDLK_RETURN;
+            break;
+          case 0xffc0: //XK_F3
+            _iCodeTouchePressee = SDLK_F3;
+            break;
+          case 0xffc1: //XK_F4
+            _iCodeTouchePressee = SDLK_F4;
+            break;
+          case 0xffc2: //XK_F5
+            _iCodeTouchePressee = SDLK_F5;
+            break;
+          case 0xffe1: //XK_Shift_L
+            _iCodeTouchePressee = SDLK_LSHIFT;
+            break;
+          case 0xffe2: //XK_Shift_R
+            _iCodeTouchePressee = SDLK_RSHIFT;
+            break;
+        }
+#endif
+            
         }
       }
       _oChaine->entreeClavier(_iCodeTouchePressee);
@@ -1120,15 +1215,23 @@ void _score::executeOrder(int _iFlag)
   // test les touches speciales
   switch (_iCodeTouchePressee)
   {
+#ifdef SDL_TLK
+    case SDLK_DOWN:
+#else      
     case XK_Down:
+#endif
       if(++iTxtPosY >= iTXT_NBRELIGNES)
       {
         iTxtPosY = iTXT_NBRELIGNES - 1;
         supprimeLigne(0);
       }
       break;
+#ifdef SDL_TLK
+    case SDLK_UP:
+#else      
     case XK_Up:
-      if(iTxtPosY == 0)
+#endif
+    if(iTxtPosY == 0)
       {
         insertLigne(iTxtPosY);
       }
@@ -1137,25 +1240,45 @@ void _score::executeOrder(int _iFlag)
         iTxtPosY--;
       }
       break;
+#ifdef SDL_TLK
+    case SDLK_INSERT:
+#else      
     case XK_Insert:                                           // touche INSERT pressee
+#endif
       insertLigne(iTxtPosY);
       break;
+#ifdef SDL_TLK
+    case SDLK_RETURN:
+#else      
     case XK_Return:                                           // touche RETURN pressed ? (ASCII=13)
-      if(++iTxtPosY >= iTXT_NBRELIGNES)
+#endif
+    if(++iTxtPosY >= iTXT_NBRELIGNES)
       {
         iTxtPosY = iTXT_NBRELIGNES - 1;
         supprimeLigne(0);
       }
       iTxtPosX = 0;
       break;
+#ifdef SDL_TLK
+    case SDLK_F3:
+#else      
     case XK_F3:                                               // curseur en haut a gauche
+#endif
       iTxtPosX = 0;
       iTxtPosY = 0;
       break;
+#ifdef SDL_TLK
+    case SDLK_F4:
+#else      
     case XK_F4:                                               // curseur en haut a gauche & efface l'ecran
+#endif
       effaceCaracteres();
       break;
+#ifdef SDL_TLK 
+    case SDLK_F5:
+#else      
     case XK_F5:                                               // supprime la ligne en cours
+#endif
       supprimeLigne(iTxtPosY);
       break;
   }                                                            // fin test des touches speciales
