@@ -20,6 +20,8 @@
 // Place - Suite 330, Boston, MA  02111-1307, USA.
 //
 //*****************************************************************************
+#include "powermanga.hpp"
+#ifdef XFREE_TLK
 #define UTILISE_XSHM	1                                      //use XSHM Ximage
 #include <X11/keysym.h>
 #include <X11/keysymdef.h>
@@ -32,7 +34,6 @@
 #include <sys/shm.h>
 #include <sys/ipc.h>
 #endif
-#include "powermanga.hpp"
 //------------------------------------------------------------------------------
 Display                *pPowerMangaDisplay = 0;                //pointeur 
 Window                  pFenetreRacine = 0;                    //pointeur fenetre racine (4 octets=pointeur)
@@ -74,7 +75,7 @@ int                     iCouleurBlanche = 0;
 unsigned int            iLargeurEcranTotal = 0;                //taille d'une ligne du buffer 'ecran_ram'
 int                     vmode = 1;                             //0=resolution de 320x200 / 1=640*400 / 2=640*400 (double pixels)
 
-//..............................................................................
+//..............................................  ................................
 int                     fullscreen = 0;                        //1=marche en plein ecran
 int                     iDGAFlags;
 char                   *pDGAmemoire;
@@ -997,12 +998,16 @@ void fenetre320x200()
 //------------------------------------------------------------------------------
 void fenetre640x400()
 {
-  char                   *_pSource =
+  char *_pSource =
     ecran_ram + (BANDE_DE_CLIP * iLargeurEcranTotal) +
     (BANDE_DE_CLIP * iOctetsParPixel);
 
   //recopie l'ecran de jeu en doublant / recopy the screen by it doubling
-  copy2X_512x440(_pSource, ecran_ram640 + (iLargeurEcran * iOctetsParPixel * 32), HAUT_ECR_RAM);        // "assembler_opt.S"
+  // ("assembler_opt.S")
+  copy2X_512x440(_pSource, 
+                 ecran_ram640 + (iLargeurEcran * iOctetsParPixel * 32),
+                 HAUT_ECR_RAM
+  );
 
   //affiche dans la fenetre ......................................................
   //affiche l'ecran de jeu 
@@ -1012,7 +1017,9 @@ void fenetre640x400()
               0, 32,                                           //coordonnees sources
               0, 32,                                           //coordonnees destination
               LARG_ECR_RAM * 2, HAUT_ECR_RAM * 2);             //affiche l'ecran de jeu de 512*368
-    if(iScoreXWindow)                                          //display score number ?
+ 
+    //display score number ?
+    if(iScoreXWindow)
     {
       iScoreXWindow = 0;
       copy2X(ecran_scr + (68 * iOctetsParPixel),
@@ -1491,3 +1498,4 @@ fullscreen=0 && vmode=1
 - display sprites in "ecran_ram" (512*440)
 - copy "ecran_ram" in "ecran_ram640" (double pixels horizontal and skip a line)
 */
+#endif
